@@ -137,7 +137,10 @@ class Recipe(zc.recipe.egg.Egg):
         # add the created scripts to the buildout installed stuff, so they get removed correctly
         self.options.created(
             os.path.join(self.options["bin-directory"], "django-admin"),
-            os.path.join(self.options["bin-directory"], "django"),
+            os.path.join(
+                self.options["bin-directory"],
+                self.options.get("control-script", "django")
+            ),
         )
 
     def initialization(self):
@@ -154,3 +157,5 @@ class Recipe(zc.recipe.egg.Egg):
             self.options["project"],
             self.options["settings"]
         )
+
+    update = install
